@@ -8,6 +8,7 @@ import time
 import errno
 import random
 import shutil
+import decimal
 import inspect
 import logging
 import hashlib
@@ -24,6 +25,7 @@ from typing import *
 from abc import abstractmethod
 from PIL import Image
 from functools import reduce
+from functools import partial
 from itertools import product
 from collections import Counter
 
@@ -116,10 +118,21 @@ def update_dict(src_dict: dict, tgt_dict: dict) -> dict:
 def fix_float_to_length(num: float, length: int) -> str:
     """ Change a float number to string format with fixed length. """
 
-    str_num = f"{num:f}"
+    ctx = decimal.Context()
+    ctx.prec = 2 * length
+    d = ctx.create_decimal(repr(num))
+    str_num = format(d, "f").lower()
     if str_num == "nan":
         return f"{str_num:^{length}s}"
-    length = max(length, str_num.find("."))
+    idx = str_num.find(".")
+    if idx == -1:
+        diff = length - len(str_num)
+        if diff <= 0:
+            return str_num
+        if diff == 1:
+            return f"{str_num}."
+        return f"{str_num}.{'0' * (diff - 1)}"
+    length = max(length, idx)
     return str_num[:length].ljust(length, "0")
 
 
@@ -1426,11 +1439,11 @@ class Saving(LoggingMixin):
         for array_file in os.listdir(array_folder):
             attr_name, attr_ext = os.path.splitext(array_file)
             if attr_ext == ".npy":
-                load_method = np.load
+                load_method = partial(np.load, allow_pickle=True)
             elif attr_ext == ".lst":
 
                 def load_method(path):
-                    return np.load(path).tolist()
+                    return np.load(path, allow_pickle=True).tolist()
 
             else:
                 raise ValueError(f"unrecognized file type '{array_file}' occurred")
